/***********************************************************************************************************************************
Repository Create Command
***********************************************************************************************************************************/
#ifndef COMMAND_REPO_CREATE_H
#define COMMAND_REPO_CREATE_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Create the repository (create path, bucket, etc.)
FN_EXTERN void cmdRepoCreate(void);

#endif
